fn parse_session(
session: &Value,
origin_id: u32,
origins: &FeedOrigins,
dst_is_v6: bool,
) -> Option<u32>Expand description
Parse session, a 16-bit session ID (0-65535) tagging this target; replies echo it
back so they can be attributed to the submitting session.
When set to 0, the target is not attributed to any session (replies are reported with session 0).
Warns when setting a session for TCP/CHAOS probes (does not support session encoding).